"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyAccessToken = verifyAccessToken;
const core_1 = require("@credo-ts/core");
const OpenId4VcIssuerService_1 = require("../OpenId4VcIssuerService");
async function verifyAccessToken(agentContext, issuer, authorizationHeader) {
    const openId4VcIssuerService = agentContext.dependencyManager.resolve(OpenId4VcIssuerService_1.OpenId4VcIssuerService);
    if (!authorizationHeader || !authorizationHeader.startsWith('Bearer ')) {
        throw new core_1.CredoError('No access token provided in the authorization header');
    }
    const issuerMetadata = openId4VcIssuerService.getIssuerMetadata(agentContext, issuer);
    const accessToken = core_1.Jwt.fromSerializedJwt(authorizationHeader.replace('Bearer ', ''));
    const jwsService = agentContext.dependencyManager.resolve(core_1.JwsService);
    const { isValid, signerKeys } = await jwsService.verifyJws(agentContext, {
        jws: accessToken.serializedJwt,
        jwkResolver: () => {
            throw new Error('No JWK resolver available for access token verification');
        },
    });
    if (!isValid) {
        throw new core_1.CredoError('Signature on access token is invalid');
    }
    if (!signerKeys.map((key) => key.fingerprint).includes(issuer.accessTokenPublicKeyFingerprint)) {
        throw new core_1.CredoError('Access token was not signed by the expected issuer');
    }
    // Finally validate the JWT payload (expiry etc..)
    accessToken.payload.validate();
    if (accessToken.payload.iss !== issuerMetadata.issuerUrl) {
        throw new core_1.CredoError('Access token was not issued by the expected issuer');
    }
    if (typeof accessToken.payload.additionalClaims.preAuthorizedCode !== 'string') {
        throw new core_1.CredoError('No preAuthorizedCode present in access token');
    }
    return {
        preAuthorizedCode: accessToken.payload.additionalClaims.preAuthorizedCode,
    };
}
//# sourceMappingURL=verifyAccessToken.js.map